@@ -1,12 +1,16 @@
 # -*- coding: utf-8 -*-
 """The tgapp-smallpress package"""
 import tg, os, logging
+from tgext.pluggable import plugged, plug
 
 log = logging.getLogger('tgapp-smallpress')
 
 def plugme(app_config, options):
     tg.config['_smallpress'] = options
 
+    if 'tgext.tagging' not in plugged():
+        plug(app_config, 'tgext.tagging')
+
     def init_whoosh(app):
         try:
             from whoosh.index import create_in
@@ -32,4 +36,4 @@ def plugme(app_config, options):
         raise Exception("Smallpress can't work with prefer_toscawidgets2 option, please change it to use_toscatiwdgets2 = True")
 
     app_config.register_hook('before_config', init_whoosh)
-    return dict(appid='smallpress', global_helpers=False)
\ No newline at end of file
+    return dict(appid='smallpress', global_helpers=False)
