@@ -7,19 +7,20 @@ from tg.decorators import before_render, cached_property
 from tg.i18n import ugettext as _, lazy_ugettext as l_
 from repoze.what import predicates
 
-from smallpress.model import DBSession, Article, Attachment, Tagging, Blog
+from tgext.pluggable import app_model
+from smallpress.model import DBSession, Article, Attachment, Blog
 from smallpress.helpers import *
 from smallpress.lib.forms import UploadForm, get_article_form
 from tgext.datahelpers.validators import SQLAEntityConverter
 from tgext.datahelpers.fields import AttachedFile
-from tgext.pluggable import plug_url
+from tgext.pluggable import plug_url, plug_redirect
 from webhelpers.html.builder import HTML
 from tw.api import CSSLink
 from tw.forms import DataGrid
 from tw.forms.validators import UnicodeString
 from datetime import datetime
 from tgext.ajaxforms.ajaxform import formexpose, spinner_icon
-from tgext.tagging import TaggingController
+from tgext.tagging.controllers import TaggingController
 from tgext.crud import EasyCrudRestController
 
 try:
@@ -72,7 +73,7 @@ class RootController(TGController):
     @expose('genshi:smallpress.templates.index')
     def index(self, blog='', *args, **kw):
         articles = Article.get_published(blog).all()
-        tags = Tagging.tag_cloud_for_set(Article, articles).all()
+        tags = app_model.Tagging.tag_cloud_for_set(Article, articles).all()
         return dict(articles=articles, tags=tags, blog=blog)
 
     @expose('genshi:smallpress.templates.article')
@@ -104,10 +105,9 @@ class RootController(TGController):
     def new(self, blog=None, **kw):
         attachments_table.register_resources()
 
-        if blog:
-            blog = DBSession.query(Blog).filter_by(name=blog).first()
-
         if 'uid' not in kw:
+            if blog:
+                blog = DBSession.query(Blog).filter_by(name=blog).first()
             article = Article(author=request.identity['user'], blog=blog and blog)
 
             hooks = config['hooks'].get('smallpress.before_create_article', [])
@@ -120,24 +120,10 @@ class RootController(TGController):
             hooks = config['hooks'].get('smallpress.after_create_article', [])
             for func in hooks:
                 func(article, kw)
-
-            kw['title'] = article.title
-            kw['publish_date'] = format_date(article)
         else:
             article = DBSession.query(Article).get(kw['uid'])
 
-        value = {
-            'uid':article.uid,
-            'title':kw['title'],
-            'publish_date':kw['publish_date'],
-            'tags':kw.get('tags', ''),
-            'description':kw.get('description', ''),
-            'content':kw.get('content', ''),
-        }
-
-        return dict(article=article, value=value, blog=blog and blog.name or '',
-                    form=get_article_form(), action=url(self.mount_point+'/save'),
-                    upload_form=upload_form, upload_action=url(self.mount_point+'/attach'))
+        return plug_redirect('smallpress', '/edit/%s' % article.uid)
 
     @require(predicates.in_group('smallpress'))
     @expose('genshi:smallpress.templates.edit')
@@ -177,7 +163,7 @@ class RootController(TGController):
         article.content = kw['content']
         article.publish_date = datetime.strptime(kw['publish_date'], '%Y-%m-%d %H:%M')
         article.update_date = datetime.now()
-        Tagging.set_tags(article, kw['tags'])
+        app_model.Tagging.set_tags(article, kw['tags'])
 
         flash(_('Articles successfully saved'))
         return redirect(self.mount_point+'/manage/'+article.blog_name)
@@ -219,8 +205,11 @@ class RootController(TGController):
     @validate(dict(article=SQLAEntityConverter(Article)), error_handler=manage)
     @expose()
     def publish(self, article):
-        article.published=True
-        flash(_('Article published'))
+        if not article.content:
+            flash(_('Cannot publish an empty article'))
+        else:
+            article.published=True
+            flash(_('Article published'))
         return redirect(self.mount_point+'/manage/'+article.blog_name)
 
     @require(predicates.in_group('smallpress'))
@@ -257,5 +246,5 @@ class RootController(TGController):
         else:
             articles = Article.get_published().filter(Article.content.like('%'+text+'%')).all()
 
-        tags = Tagging.tag_cloud_for_set(Article).all()
+        tags = app_model.Tagging.tag_cloud_for_set(Article).all()
         return dict(articles=articles, tags=tags, blog='')
